@@ -1,4 +1,6 @@
-/* GIO - GLib Input, Output and Streaming Library
+/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/*
+ * GIO - GLib Input, Output and Streaming Library
  *
  * Copyright 2011 Red Hat, Inc.
  *
@@ -40,8 +42,8 @@ static GMainLoop *loop;
 
 static void
 got_proxies (GObject      *source,
-	     GAsyncResult *result,
-	     gpointer      user_data)
+             GAsyncResult *result,
+             gpointer      user_data)
 {
   GDBusMethodInvocation *invocation = user_data;
   gchar **proxies;
@@ -53,7 +55,7 @@ got_proxies (GObject      *source,
   else
     {
       g_dbus_method_invocation_return_value (invocation,
-					     g_variant_new ("(^as)", proxies));
+                                             g_variant_new ("(^as)", proxies));
       g_strfreev (proxies);
     }
 }
@@ -83,7 +85,7 @@ handle_method_call (GDBusConnection       *connection,
     g_setenv ("http_proxy", "wpad://", TRUE);
 
   g_proxy_resolver_lookup_async (resolver, lookup_url,
-				 NULL, got_proxies, invocation);
+                                 NULL, got_proxies, invocation);
 }
 
 static const GDBusInterfaceVTable interface_vtable =
@@ -103,12 +105,12 @@ on_bus_acquired (GDBusConnection *connection,
 
   introspection_data = g_dbus_node_info_new_for_xml (introspection_xml, NULL);
   g_dbus_connection_register_object (connection,
-				     "/org/gtk/GLib/PACRunner",
-				     introspection_data->interfaces[0],
-				     &interface_vtable,
-				     NULL,
-				     NULL,
-				     &error);
+                                     "/org/gtk/GLib/PACRunner",
+                                     introspection_data->interfaces[0],
+                                     &interface_vtable,
+                                     NULL,
+                                     NULL,
+                                     &error);
   if (error)
     g_error ("Could not register server: %s", error->message);
 }
@@ -138,6 +140,10 @@ main (int argc, char *argv[])
   g_unsetenv ("DESKTOP_SESSION");
   g_unsetenv ("KDE_FULL_SESSION");
 
+  /* Unset variables that libproxy would look at if it were smarter, and which
+   * it might possibly look at in the future. Just covering our bases. */
+  g_unsetenv ("XDG_CURRENT_DESKTOP");
+
   /* Unset static proxy settings */
   g_unsetenv ("http_proxy");
   g_unsetenv ("HTTP_PROXY");
